
# LAPRAS



Lapras is developed to facilitate the dichotomy model development work


## Install


via pip

```bash
pip install lapras
```

via source code

```bash
python setup.py install
```

## Usage

```python

```

## Documents

A simple API



